# Installation

To Install pyBloxy you only have to do this:
``pip install pyBloxyCola``

And for windows users:
``py -m pip install pyBloxyCola``

The requirements for pyBloxyCola is python 3.8!

# Example:

You can fetch group data in JSON with: (more will be in docs)

```py
from pyBloxyCola import pyBloxyCola

print(pyBloxyCola().getGroupInfoInJSON(1))
```
